<!DOCTYPE html>
{% load static %}
<html lang="en">
<head>
  <meta charset="UTF-8" />
  <meta name="viewport" content="width=device-width, initial-scale=1.0" />
  <title>QLab</title>
  <link
    href="https://fonts.googleapis.com/css2?family=IBM+Plex+Mono:ital,wght@0,400;0,500;0,600;1,400&family=IBM+Plex+Sans:wght@300;400;500;600&family=Bebas+Neue&display=swap"
    rel="stylesheet"
  />
  <link rel="stylesheet" href="{% static 'qlab/qlab.css' %}" />
</head>
<body>
  <div id="qlab-root"></div>
  <script>
    window.__QLAB_API_BASE__ = "{{ QLAB_API_BASE|escapejs }}";
    window.__CSRF_TOKEN__ = "{{ csrf_token }}";
  </script>
  <script type="module" src="{% static 'qlab/qlab.js' %}"></script>
</body>
</html>
